#!/bin/bash

# oracle-init.sh
# by Chris Runge <crunge@redhat.com>
# August 22, 2003

# run this script as root to configure a Red Hat Enterprise Linux AS/ES 2.1
# system for the installation of Oracle9i Release 2 (9.2.0)

#
# set environment specifics here
#

# group ID for dba group
DBA_GID=400
# group ID for oper group
OPER_GID=401
# group ID for oinstall group
OINSTALL_GID=402
# user ID for oracle user
ORACLE_UID=403
# user name for oracle user
ORACLE_OWNER=oracle
# ORACLE_BASE for Oracle software
ORACLE_BASE=/opt/oracle
# database SID
ORACLE_SID=orcl
# Oracle version 
ORACLE_VERSION=9.2.0

#
# output description
#

echo
echo "This script will configure a Red Hat Enterprise Linux AS/ES 2.1 system"
echo "for the installation of Oracle9i Release 2 (9.2.0)."
echo 

#
# check to make sure we're running as root
#
if [[ ${UID} != 0 ]]; then
    echo "Exiting... You must be root to run this script."
    exit 1
fi

#
# make sure the user wants to run this script
# 

while true; do
    echo -n "Continue? yes/no [yes]: "
    read ANS
    ANS=${ANS:=yes}
    if [ $ANS = yes ] || [ $ANS = y ]; then
        break
    elif [ $ANS = no ] || [ $ANS = n ]; then
        echo "No changes have been made."
        exit 1
    fi
done

#
# add users and groups
#

/usr/sbin/groupadd -g $DBA_GID dba
/usr/sbin/groupadd -g $OPER_GID oper
/usr/sbin/groupadd -g $OINSTALL_GID oinstall
/usr/sbin/useradd -g oinstall \
    -G dba,oper \
    -u $ORACLE_UID \
    -s /bin/bash \
    $ORACLE_OWNER

#
# prepare target directories
# 

mkdir -p $ORACLE_BASE
chown $ORACLE_OWNER.dba $ORACLE_BASE
chmod 775 $ORACLE_BASE

#
# setup the oracle user's environment
# 

cat > /home/$ORACLE_OWNER/.oraclerc << EOF
# Configuration settings for Oracle9i Release 2 (9.2.0)
umask 022
export ORACLE_BASE=$ORACLE_BASE
export ORACLE_HOME=\$ORACLE_BASE/product/$ORACLE_VERSION
export ORACLE_SID=$ORACLE_SID
export ORA_NLS33=\$ORACLE_HOME/ocommon/nls/admin/data
export TNS_ADMIN=\$ORACLE_HOME/network/admin
export PATH=\$ORACLE_HOME/bin:/bin:/usr/bin:/usr/local/bin:/usr/bin/X11:/usr/X11R6/bin:\$HOME/bin
export LD_LIBRARY_PATH=\$ORACLE_HOME/lib:\$LD_LIBRARY_PATH
EOF

chown $ORACLE_OWNER.oinstall /home/oracle/.oraclerc

cat >> /home/$ORACLE_OWNER/.bash_profile << EOF

# Configure Oracle environment
. ~/.oraclerc
EOF

#
# configure the kernel for Oracle
#

cat >> /etc/sysctl.conf << EOF
# Parameters for Oracle9i Release 2 (9.2.0)
kernel.sem = 250 32000 100 128
kernel.shmmax = 2147483648
kernel.shmmni = 4096
kernel.shmall = 2097152
fs.file-max = 65536
net.ipv4.ip_local_port_range = 1024 65000
EOF

# enact changes now
/sbin/sysctl -p > /dev/null 2>&1

#
# configure networking for Oracle9i
#

cat >> /etc/resolv.conf << EOF
# Parameters for Oracle9i Release 2 (9.2.0)
options attempts:5
options timeout:15
EOF

#
# configure PAM limits for oracle user
# - maximum number of open files
# - maximum number of processes
#

cat >> /etc/security/limits.conf << EOF
# Configuration settings for Oracle9i Release 2 (9.2.0)
$ORACLE_OWNER           soft    nofile          8192
$ORACLE_OWNER           hard    nofile          8192
$ORACLE_OWNER           soft    nproc           65536
$ORACLE_OWNER           hard    nproc           65536
EOF

#
# modify /etc/sysconfig/oracle (used by initscripts)
# 

# modify /etc/sysconfig/oracle
perl -pi -e "s%^ORA_HOME=.*$%ORA_HOME=$ORACLE_BASE/product/$ORACLE_VERSION%" \
    /etc/sysconfig/oracle
perl -pi -e "s%^ORA_OWNER=.*$%ORA_OWNER=$ORACLE_OWNER%" \
    /etc/sysconfig/oracle

# prompt for a password for the oracle user
/usr/bin/passwd $ORACLE_OWNER
